@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for ce service client
 
@@ -7,23 +8,20 @@ Usage::
     import boto3
     from mypy_boto3_ce import CostExplorerClient
 
-    session = boto3.Session()
-
     client: CostExplorerClient = boto3.client("ce")
-    session_client: CostExplorerClient = session.client("ce")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_ce.type_defs import (
     CostCategoryRuleTypeDef,
     CreateCostCategoryDefinitionResponseTypeDef,
     DateIntervalTypeDef,
     DeleteCostCategoryDefinitionResponseTypeDef,
     DescribeCostCategoryDefinitionResponseTypeDef,
-    ExpressionTypeDef,
     GetCostAndUsageResponseTypeDef,
     GetCostAndUsageWithResourcesResponseTypeDef,
     GetCostForecastResponseTypeDef,
@@ -68,14 +66,14 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client)
+    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.can_paginate)
         """
 
     def create_cost_category_definition(
@@ -85,21 +83,21 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         """
 
     def generate_presigned_url(
@@ -110,33 +108,33 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         """
 
     def get_cost_and_usage(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         """
 
     def get_cost_and_usage_with_resources(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         """
 
     def get_cost_forecast(
@@ -152,11 +150,11 @@ class CostExplorerClient:
             "NORMALIZED_USAGE_AMOUNT",
         ],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"],
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         """
 
     def get_dimension_values(
@@ -198,7 +196,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         """
 
     def get_reservation_coverage(
@@ -206,12 +204,12 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         Metrics: List[str] = None,
         NextPageToken: str = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -234,7 +232,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         """
 
     def get_reservation_utilization(
@@ -242,23 +240,23 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         NextPageToken: str = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         """
 
     def get_rightsizing_recommendation(
         self,
         Service: str,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         """
 
     def get_savings_plans_coverage(
@@ -266,13 +264,13 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         Metrics: List[str] = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -291,31 +289,31 @@ class CostExplorerClient:
         AccountScope: Literal["PAYER", "LINKED"] = None,
         NextPageToken: str = None,
         PageSize: int = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         """
 
     def get_savings_plans_utilization(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"] = None,
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         """
 
     def get_savings_plans_utilization_details(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         """
 
     def get_tags(
@@ -326,7 +324,7 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_tags)
         """
 
     def get_usage_forecast(
@@ -342,18 +340,18 @@ class CostExplorerClient:
             "NORMALIZED_USAGE_AMOUNT",
         ],
         Granularity: Literal["DAILY", "MONTHLY", "HOURLY"],
-        Filter: "ExpressionTypeDef" = None,
+        Filter: Dict[str, Any] = None,
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         """
 
     def update_cost_category_definition(
@@ -363,5 +361,5 @@ class CostExplorerClient:
         Rules: List["CostCategoryRuleTypeDef"],
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.6/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         """
